@@ -19,12 +19,14 @@ public:
 	QLabelZ(QWidget *parent, Qt::WindowFlags f);
 	~QLabelZ();
 	void paintEvent(QPaintEvent* event);
+
 signals:
 	void clicked ();
 
 protected:
     void mousePressEvent(QMouseEvent *ev);
     void mouseReleaseEvent(QMouseEvent *ev);
+
 private:
     bool select;
 };
@@ -34,7 +36,7 @@ class LoginDialog : public QWidget
 	Q_OBJECT
 
 public:
-	LoginDialog(bool firstTime, eWallet * paTarget);
+	LoginDialog(bool firstTime, QWidget * paTarget);
 	~LoginDialog();
 
 	void resetF ();
@@ -42,6 +44,9 @@ public:
 	void orientationChanged(int o);
 	void focus ();
 
+signals:
+	bool finalWithPassword (QString pass);
+
 private slots:
 	void select(const QString& a);
 	void acceptS();
@@ -55,7 +60,7 @@ private:
 	//void focusOutEvent ( QFocusEvent * event );
 	//QString current;
 	//QString repeat;
-	eWallet * parent;
+	//eWallet * parent;
 	QDialogButtonBox* dlgBtnBox;
 	int NTimes;
 	bool isFirstTime;
