@@ -19,6 +19,7 @@
  * TODO anti robo (avisos por email - sms
  * TODO be able to copy sms and others messages (and contacts?) into wallet.
  * TODO add configuration file to backup
+ * TODO get card properties from scanner
  */
 
 #include "utils.h"
@@ -31,6 +32,7 @@
 #include "eWallet.h"
 #include "Constants.h"
 #include "DatabaseManager.h"
+#include "AntiTheftManager.h"
 #include <Qt>
 #include <QtGui>
 #include <QFile>
@@ -49,6 +51,98 @@
 
 DatabaseManager * dbManager;
 
+class eWallet::MyDelegate : public QStyledItemDelegate  {
+	eWallet & parentWallet;
+
+	public:
+
+	MyDelegate(eWallet & w, QObject *parent=0): QStyledItemDelegate (parent), parentWallet (w)
+	{ 	}
+
+	void paint ( QPainter * painter, const QStyleOptionViewItem & option, const QModelIndex & index ) const{
+		if(option.state & QStyle::State_Selected){
+			painter->fillRect(option.rect, option.palette.color(QPalette::Highlight));
+		}
+
+		QVariant _index = index.data(Qt::UserRole + 1);
+		QString title = index.data(Qt::DisplayRole).toString();
+
+		//qDebug () << "paiting " << title;
+
+		if (_index.isNull()) {
+			painter->save();
+			QFont ft = option.font;
+			ft.setBold(true);
+			painter->setFont(ft);
+			QRect r = option.rect.adjusted(15, 0, 0, 0);
+			painter->drawText(r.left(), r.top()-15, r.width(), r.height(), Qt::AlignBottom|Qt::AlignLeft|Qt::TextWordWrap, title, &r);
+			painter->restore();
+		}
+		else {
+			QVariant val = index.data(Qt::DecorationRole);
+			Target * target = parentWallet.list.at(_index.toInt());
+			QString description = target->getSummary();
+
+			QIcon pixmap;
+			if (val.isNull()) {
+				qDebug () << "getting image " << title;
+
+				if (target->getPictureSmall() != NULL) {
+					pixmap = QPixmap::fromImage(*target->getPictureSmall());
+
+					// at this moment we don't need anymore original images!
+					target->freeResources();
+				} else {
+					QString tmp = ":/resources/empty_";
+					tmp += target->type.simplified().replace(' ', '_');
+					tmp += ".png";
+
+					if (QResource(tmp).isValid()) {
+						pixmap = QPixmap(tmp);
+					} else {
+						pixmap = QPixmap(":/resources/empty_Others.png");
+					}
+				}
+
+				parentWallet.fnListWidget->item(_index.toInt())->setIcon(pixmap);
+				//index.data(Qt::DecorationRole) = pixmap;
+			}
+			else {
+				pixmap = qvariant_cast<QIcon>(val);
+			}
+
+			QRect r = option.rect.adjusted(0, 0, option.decorationSize.width(), option.decorationSize.height());
+			pixmap.paint(painter, 5, r.top () + 5, SMALL_WIDTH, SMALL_HEIGH, option.decorationAlignment, QIcon::Normal);
+
+			painter->save();
+			QFont ft = option.font;
+			ft.setBold(true);
+			painter->setFont(ft);
+			r = option.rect.adjusted(SMALL_WIDTH + 10, 0, 0, -SMALL_HEIGH/2);
+			painter->drawText(r.left(), r.top(), r.width(), r.height(), Qt::AlignBottom|Qt::AlignLeft|Qt::TextWordWrap, title, &r);
+
+			r = option.rect.adjusted(SMALL_WIDTH + 15, SMALL_HEIGH/2+10, 0, 0);
+			ft.setBold(false);
+			ft.setItalic(true);
+			ft.setPointSize(ft.pointSize()-4);
+			painter->setFont(ft);
+			painter->drawText(r.left(), r.top(), r.width(), r.height(), Qt::AlignLeft|Qt::TextWordWrap, description, &r);
+			painter->restore();
+		}
+	}
+
+	QSize sizeHint ( const QStyleOptionViewItem & option, const QModelIndex & index ) const {
+		QVariant val = index.data(Qt::DecorationRole);
+		if (val.isNull()) {
+			return QSize(200, 70);
+		}
+		else {
+			return QSize(200, SMALL_HEIGH+10);
+		}
+	}
+};
+
+
 eWallet::eWallet(QString * group, eWallet * _parent, QWidget *parent) :
 	QMainWindow(parent) {
 	setWindowTitle("Wallet");
@@ -60,6 +154,9 @@ eWallet::eWallet(QString * group, eWallet * _parent, QWidget *parent) :
 	centralWidget = NULL;
 	currentGroup = group;
 
+//	this->originalDelegate = _parent->originalDelegate;
+//	this->newDelegate = _parent->newDelegate;
+
 #ifdef Q_WS_MAEMO_5
 	this->setAttribute(Qt::WA_Maemo5AutoOrientation, true);
 	//connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged(int)));
@@ -97,18 +194,18 @@ eWallet::eWallet(QString * group, eWallet * _parent, QWidget *parent) :
 //     ::umask(0);
 // #endif
 // }
-class I: public QThread {
-public:
-	static void sleep(unsigned long secs) {
-		QThread::sleep(secs);
-	}
-	static void msleep(unsigned long msecs) {
-		QThread::msleep(msecs);
-	}
-	static void usleep(unsigned long usecs) {
-		QThread::usleep(usecs);
-	}
-};
+//class I: public QThread {
+//public:
+//	static void sleep(unsigned long secs) {
+//		QThread::sleep(secs);
+//	}
+//	static void msleep(unsigned long msecs) {
+//		QThread::msleep(msecs);
+//	}
+//	static void usleep(unsigned long usecs) {
+//		QThread::usleep(usecs);
+//	}
+//};
 
 eWallet::eWallet(QWidget *parent) :
 	QMainWindow(parent) {
@@ -407,6 +504,11 @@ void eWallet::showList(bool interactive) {
 	//vboxlayout->addWidget(backButton);
 
 	fnListWidget = new QListWidget(this);
+	this->originalDelegate = new MyDelegate(*this, fnListWidget);// TODO fnListWidget->itemDelegate();
+	this->newDelegate = new MyDelegate(*this, fnListWidget);
+
+	//fnListWidget->setItemDelegate(new MyDelegate(fnListWidget));
+
 	fnListWidget->setSortingEnabled(false);
 	fnListWidget->setFocusPolicy(Qt::NoFocus);
 	vboxlayout->addWidget(fnListWidget);
@@ -730,7 +832,8 @@ bool eWallet::openDataBase(const QString & pas) {
 	if (!res) {
 		if (++times > 3) {
 			exit(3);
-		} else {
+		}
+		else {
 			if (!::dbManager->isReady()) {
 #ifdef Q_WS_MAEMO_5
 				show_banner (this, tr("Wrong password"));
@@ -744,6 +847,13 @@ bool eWallet::openDataBase(const QString & pas) {
 				delete messageBox;
 				messageBox = 0;
 #endif
+
+				if (times == 2) {
+#ifndef OPEN_SOURCE_VERSION
+					AntiTheftManager * manager = new AntiTheftManager (this);
+					manager->notifyFailure ();
+#endif
+				}
 			}
 		}
 	} else {
@@ -1122,6 +1232,8 @@ QPixmap eWallet::getImage(Target * target) {
 void eWallet::showGroups(bool reset) {
 	//qDebug () << "show Groups " << reset;
 
+	fnListWidget->setItemDelegate(originalDelegate);
+
 	int current = fnListWidget->currentRow();
 
 	// Clean previous items from the layout
@@ -1183,6 +1295,8 @@ void eWallet::showTargets(bool reset, const QString * filter) {
 #endif
 	//qDebug () << "show Targets " << reset;
 
+	fnListWidget->setItemDelegate(newDelegate);
+
 	int current = fnListWidget->currentRow();
 
 	//#ifdef Q_WS_MAEMO_5
@@ -1219,13 +1333,16 @@ void eWallet::showTargets(bool reset, const QString * filter) {
 	for (int i = 0; i < list.size(); i++) {
 		Target * target = list.at(i);
 
-		QListWidgetItem* listitem = new QListWidgetItem(getImage(target),
-				target->getName());
-		//listitem->set(target->getSummary());
+		//QListWidgetItem* listitem = new QListWidgetItem(getImage(target),target->getName());
+		QListWidgetItem* listitem = new QListWidgetItem(target->getName());
+		listitem->setData(Qt::UserRole + 1, QVariant (i));
+
 		fnListWidget->addItem(listitem);
 
 	}
 
+	//fnListWidget->setItemDelegate(new MyDelegate(fnListWidget));
+
 	filterBy(currentFilter);
 
 	if (current >= 0 && current <= list.size())
@@ -1252,6 +1369,9 @@ void eWallet::createMenu() {
 		}
 #endif
 		menuBar()->addAction(tr("Options"), this, SLOT(options()));
+#ifndef OPEN_SOURCE_VERSION
+		menuBar()->addAction(tr("Anti-Theft options"), this, SLOT(optionsAntiTheft()));
+#endif
 		menuBar()->addAction(tr("Exit"), QApplication::instance(), SLOT(quit()));
 	}
 	else {
@@ -1273,6 +1393,9 @@ void eWallet::createMenu() {
 		menuBar()->addAction(tr("Templates"), this, SLOT(editTemplates()));
 #endif
 		menuBar()->addAction(tr("Options"), this, SLOT(options()));
+#ifndef OPEN_SOURCE_VERSION
+		menuBar()->addAction(tr("Anti-Theft options"), this, SLOT(optionsAntiTheft()));
+#endif
 		menuBar()->addAction(tr("About"), this, SLOT(about()));
 		menuBar()->addAction(tr("Exit"), QApplication::instance(), SLOT(quit()));
 	}
@@ -1304,6 +1427,7 @@ void eWallet::createMenu() {
 #endif
 		m->addAction(tr("Options"), this, SLOT(options()));
 #ifndef OPEN_SOURCE_VERSION
+		m->addAction(tr("Anti-Theft options"), this, SLOT(optionsAntiTheft()));
 		m->addAction(tr("Templates"), this, SLOT(editTemplates()));
 #endif
 		m->addSeparator();
@@ -1343,8 +1467,9 @@ bool eWallet::_insertTarget(Target* target) {
 			else
 				qSort(list.begin(), list.end(), sortTargetsDES);
 
-			QListWidgetItem* listitem = new QListWidgetItem(getImage(target),
-					target->name);
+			QListWidgetItem* listitem = new QListWidgetItem(getImage(target), target->name);
+			//QListWidgetItem* listitem = new QListWidgetItem(target->name);
+			//listitem->setData(Qt::UserRole + 1, *target);
 
 			int pos = list.indexOf(target);
 			qDebug() << "position of new " << pos << " OF " << list.size();
@@ -1353,10 +1478,15 @@ bool eWallet::_insertTarget(Target* target) {
 				qDebug() << "insert position of new " << pos << " OF "
 						<< list.size();
 				fnListWidget->insertItem(pos, listitem);
+
+				listitem->setData(Qt::UserRole + 1, QVariant(pos));
+
 			} else {
 				qDebug() << "append position of new " << pos << " OF "
 						<< list.size();
 				fnListWidget->addItem(listitem);
+
+				listitem->setData(Qt::UserRole + 1, QVariant(list.size()));
 			}
 			fnListWidget->setCurrentItem(listitem);
 		} else {
@@ -2190,6 +2320,7 @@ void eWallet::importXml() {
 									t->freeFieldList();
 									t->freeResources();
 									delete t;
+									t = NULL;
 
 									QApplication::instance()->processEvents();
 
@@ -2685,6 +2816,14 @@ void eWallet::options() {
 	}
 }
 
+void eWallet::optionsAntiTheft() {
+	if (optionsAntiThefDlg.isNull()) {
+		optionsAntiThefDlg = new AntiTheftOptionsDialog(this);
+		optionsAntiThefDlg->setMinimumSize(size().width(), size().height() - 100);
+		optionsAntiThefDlg->exec();
+	}
+}
+
 void eWallet::about() {
 	this->setStyleSheet("QMessageBox QLabel :link { color: #FF0000; }");
 #ifdef OPEN_SOURCE_VERSION
