@@ -13,6 +13,7 @@
 #include "DatabaseManager.h"
 #include "DetailedWindow.h"
 #include "OptionsDialog.h"
+#include "AntiTheftOptionsDialog.h"
 #include "RenameGroupDialog.h"
 #include "DetailedWindow.h"
 #include "LoginDialog.h"
@@ -59,9 +60,10 @@ public slots:
 	void changeMode ();
 
 private:
-//	bool event (QEvent *event);
-////	void swipeTriggered (QSwipeGesture *gesture);
-//	bool gestureEvent (QGestureEvent *event);
+	class MyDelegate;
+
+	QAbstractItemDelegate * originalDelegate;
+	QAbstractItemDelegate * newDelegate;
 
 	void initTemplates ();
 
@@ -115,6 +117,7 @@ private slots:
 	void _hideSearch ();
 	void about ();
 	void options ();
+	void optionsAntiTheft ();
 	void import();
 	void exportData();
 	void exportXml();
@@ -131,6 +134,7 @@ private slots:
 private:
 	QSettings settings;
 	QPointer<OptionsDialog> optionsDlg;
+	QPointer<AntiTheftOptionsDialog> optionsAntiThefDlg;
 
 	void askPassword ();
 	void askAgainPassword ();
